@@ -19,23 +19,13 @@
 using namespace Akregator;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorBrowserConfig, "akregator_config_browser.json")
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMAkregatorBrowserConfig::KCMAkregatorBrowserConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , m_widget(new QWidget(this))
-#else
-KCMAkregatorBrowserConfig::KCMAkregatorBrowserConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KCMAkregatorBrowserConfig::KCMAkregatorBrowserConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , m_widget(new QWidget(widget()))
-#endif
 {
     Ui::SettingsBrowser ui;
     ui.setupUi(m_widget);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto layout = new QVBoxLayout(this);
-#else
     auto layout = new QVBoxLayout(widget());
-#endif
     layout->addWidget(m_widget);
 
     connect(ui.kcfg_ExternalBrowserUseCustomCommand, &QAbstractButton::toggled, ui.kcfg_ExternalBrowserCustomCommand, &QWidget::setEnabled);
@@ -43,3 +33,5 @@ KCMAkregatorBrowserConfig::KCMAkregatorBrowserConfig(QObject *parent, const KPlu
 }
 
 #include "akregator_config_browser.moc"
+
+#include "moc_akregator_config_browser.cpp"
