@@ -14,22 +14,11 @@
 using namespace Akregator;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorSecurityConfig, "akregator_config_security.json")
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-
-KCMAkregatorSecurityConfig::KCMAkregatorSecurityConfig(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , m_widget(new QWidget(this))
-#else
-KCMAkregatorSecurityConfig::KCMAkregatorSecurityConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KCMAkregatorSecurityConfig::KCMAkregatorSecurityConfig(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , m_widget(new QWidget(widget()))
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QHBoxLayout(this);
-#else
     auto lay = new QHBoxLayout(widget());
-#endif
     lay->setContentsMargins({});
     Ui::SettingsSecurity ui;
     ui.setupUi(m_widget);
@@ -39,3 +28,5 @@ KCMAkregatorSecurityConfig::KCMAkregatorSecurityConfig(QObject *parent, const KP
 }
 
 #include "akregator_config_security.moc"
+
+#include "moc_akregator_config_security.cpp"
