@@ -26,6 +26,7 @@
 #include "akregator_debug.h"
 #include <KActionCollection>
 #include <KActionMenu>
+#include <KColorSchemeMenu>
 #include <KGuiItem>
 #include <KLocalizedString>
 #include <KStandardAction>
@@ -94,7 +95,7 @@ private:
 class ActionManagerImpl::ActionManagerImplPrivate
 {
 public:
-    Q_REQUIRED_RESULT QString quickSearchLineText() const;
+    [[nodiscard]] QString quickSearchLineText() const;
     NodeSelectVisitor *nodeSelectVisitor = nullptr;
     ArticleListView *articleList = nullptr;
     SubscriptionListView *subscriptionListView = nullptr;
@@ -436,7 +437,7 @@ void ActionManagerImpl::initMainWidget(MainWidget *mainWidget)
     connect(d->mQuickSearchAction, &QAction::triggered, mainWidget, &MainWidget::slotFocusQuickSearch);
 
     auto manager = new KColorSchemeManager(this);
-    coll->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+    coll->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
     setArticleActionsEnabled(false);
 }
@@ -699,3 +700,5 @@ QString ActionManagerImpl::ActionManagerImplPrivate::quickSearchLineText() const
 {
     return mQuickSearchAction->shortcut().toString();
 }
+
+#include "moc_actionmanagerimpl.cpp"
