@@ -9,10 +9,8 @@
 #include "aboutdata.h"
 #include "akregator_debug.h"
 #include "akregator_options.h"
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include "akregratormigrateapplication.h"
-#endif
 #include "mainwindow.h"
+#include "trayicon.h"
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/akregatoruserfeedbackprovider.h"
 #endif
@@ -55,6 +53,9 @@ int Application::activate(const QStringList &args, const QString &workingDir)
             if (!parser->isSet(QStringLiteral("hide-mainwindow"))) {
                 mMainWindow->show();
             }
+            if (Akregator::TrayIcon::getInstance() && !Akregator::TrayIcon::getInstance()->associatedWindow()) {
+                Akregator::TrayIcon::getInstance()->setAssociatedWindow(mMainWindow->windowHandle());
+            }
             akr.call(QStringLiteral("openStandardFeedList"));
         }
 
@@ -67,12 +68,8 @@ int Application::activate(const QStringList &args, const QString &workingDir)
 int main(int argc, char **argv)
 {
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     Akregator::Application app(argc, &argv);
-    KLocalizedString::setApplicationDomain("akregator");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("akregator"));
 
     KCrash::initialize();
 
@@ -99,10 +96,6 @@ int main(int argc, char **argv)
         qCWarning(AKREGATOR_LOG) << "akregator is already running, exiting.";
         exit(0);
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    AkregratorMigrateApplication migrate;
-    migrate.migrate();
-#endif
     // see if we are starting with session management
     if (app.isSessionRestored()) {
         auto mainWindow = new Akregator::MainWindow();
