@@ -21,7 +21,7 @@ public:
     void needToRestoreCrashedSession();
 
     void setMainWidget(Akregator::MainWidget *mainWidget);
-    Q_REQUIRED_RESULT bool previousSessionCrashed() const;
+    [[nodiscard]] bool previousSessionCrashed() const;
 
 Q_SIGNALS:
     void restoreSession(Akregator::CrashWidget::CrashAction type);
